@@ -18,12 +18,19 @@ from .S19 import (
     BMMinerS19,
     BMMinerS19a,
     BMMinerS19aPro,
+    BMMinerS19Hydro,
+    BMMinerS19i,
     BMMinerS19j,
     BMMinerS19jNoPIC,
     BMMinerS19jPro,
+    BMMinerS19jXP,
+    BMMinerS19KPro,
     BMMinerS19L,
+    BMMinerS19Plus,
     BMMinerS19Pro,
+    BMMinerS19ProHydro,
     BMMinerS19ProPlus,
+    BMMinerS19ProPlusHydro,
     BMMinerS19XP,
 )
 from .T19 import BMMinerT19
