@@ -16,9 +16,19 @@
 
 from .S19 import (
     BOSMinerS19,
+    BOSMinerS19a,
+    BOSMinerS19aPro,
     BOSMinerS19j,
     BOSMinerS19jNoPIC,
     BOSMinerS19jPro,
+    BOSMinerS19jProNoPIC,
+    BOSMinerS19jProPlus,
+    BOSMinerS19jProPlusNoPIC,
+    BOSMinerS19kProNoPIC,
+    BOSMinerS19Plus,
     BOSMinerS19Pro,
+    BOSMinerS19ProPlusHydro,
+    BOSMinerS19XP,
+    BOSMinerS19XPHydro,
 )
 from .T19 import BOSMinerT19
