@@ -18,10 +18,13 @@ from .S19 import (
     VNishS19,
     VNishS19a,
     VNishS19aPro,
+    VNishS19i,
     VNishS19j,
     VNishS19jPro,
+    VNishS19kPro,
     VNishS19NoPIC,
     VNishS19Pro,
+    VNishS19ProHydro,
     VNishS19XP,
 )
 from .T19 import VNishT19
